@@ -277,7 +277,7 @@ namespace gbrainy.Core.Main
 		protected void InitDraw (CairoContextEx gr, int width, int height, bool rtl)
 		{
 			gr.Scale (width, height);
-			gr.Color = default_color;
+			gr.SetSourceColor (default_color);
 			gr.LineWidth = LineWidth;
 			// Not all Cairo surfaces have a default font size (like PDF)
 			gr.SetPangoNormalFontSize ();
