@@ -149,7 +149,7 @@ namespace gbrainy.Games.Memory
 
 		public override void DrawPossibleAnswers (CairoContextEx gr, int area_width, int area_height, bool rtl)
 		{
-			gr.Color = new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, 1);
+			gr.SetSourceColor (new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, 1));
 
 			if (Answer.Draw ==  true) {
 				DrawAllFigures (gr, start_x_ans, start_y);
@@ -172,7 +172,7 @@ namespace gbrainy.Games.Memory
 			double org_x = x;
 
 			DrawGrid (gr, x, y);
-			gr.Color = new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha);
+			gr.SetSourceColor (new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha));
 			for (int figure = 0; figure < figures.Count; figure++, col++)
 			{
 				fig = figures[figure];
@@ -226,7 +226,7 @@ namespace gbrainy.Games.Memory
 
 		private void DrawGrid (CairoContextEx gr, double x, double y)
 		{
-			gr.Color = new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha);
+			gr.SetSourceColor (new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha));
 			for (int column = 0; column < columns; column++) {
 				for (int row = 0; row < rows; row++) {
 					gr.Rectangle (x + column * rect_w, y + row * rect_h, rect_w, rect_h);
